@@ -195,9 +195,8 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 		if (error) {
 			panel_error_dialog (gdk_screen_get_default (),
 					    "cannot_load_pixbuf", TRUE,
-					    _("Failed to load image %s"),
+					    _("Could not load icon"),
 					    "%s",
-					    button->filename,
 					    error);
 			g_free (error);
 		}
@@ -543,7 +542,10 @@ button_widget_button_press (GtkWidget *widget, GdkEventButton *event)
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
 
-	if (event->button == 1 && BUTTON_WIDGET (widget)->activatable)
+	if (event->button == 1 && BUTTON_WIDGET (widget)->activatable &&
+	/* we don't want to have two/three "click" events for double/triple
+	 * clicks. FIXME: this is only a workaround, waiting for bug 159101 */
+	    event->type == GDK_BUTTON_PRESS)
 		return GTK_WIDGET_CLASS (parent_class)->button_press_event (widget, event);
 
 	return FALSE;
