@@ -64,6 +64,110 @@ enum {
 
 static GObjectClass *parent_class;
 
+static gboolean
+panel_menu_bar_enter_applications (GtkWidget        *widget,
+				   GdkEventCrossing *event,
+				   PanelMenuBar     *menubar)
+{
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      _("Browse and run installed applications"),
+			      NULL);
+	return FALSE;
+}
+
+static gboolean
+panel_menu_bar_enter_places (GtkWidget        *widget,
+			     GdkEventCrossing *event,
+			     PanelMenuBar     *menubar)
+{
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      _("Access documents, folders and network places"),
+			      NULL);
+	return FALSE;
+}
+
+static gboolean
+panel_menu_bar_enter_desktop (GtkWidget        *widget,
+			      GdkEventCrossing *event,
+			      PanelMenuBar     *menubar)
+{
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      _("Change desktop appearance and behavior, get help, or log out"),
+			      NULL);
+	return FALSE;
+}
+
+static gboolean
+panel_menu_bar_reinit_tooltip (GtkWidget    *widget,
+			       PanelMenuBar *menubar)
+{
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      "", NULL);
+
+	return FALSE;
+}
+
+static gboolean
+panel_menu_bar_hide_tooltip (GtkWidget    *widget,
+			     PanelMenuBar *menubar)
+{
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      NULL, NULL);
+
+	return FALSE;
+}
+
+static void
+panel_menu_bar_setup_tooltip (PanelMenuBar *menubar)
+{
+	/* Update tooltip when we enter the menu items */
+	g_signal_connect (menubar->priv->applications_item,
+			  "enter-notify-event",
+			  G_CALLBACK (panel_menu_bar_enter_applications),
+			  menubar);
+	g_signal_connect (menubar->priv->places_item,
+			  "enter-notify-event",
+			  G_CALLBACK (panel_menu_bar_enter_places),
+			  menubar);
+	g_signal_connect (menubar->priv->desktop_item,
+			  "enter-notify-event",
+			  G_CALLBACK (panel_menu_bar_enter_desktop),
+			  menubar);
+
+	//FIXME: this doesn't handle the right-click case. Sigh.
+	/* Hide tooltip if a menu is activated */
+	g_signal_connect (menubar->priv->applications_item,
+			  "activate",
+			  G_CALLBACK (panel_menu_bar_hide_tooltip),
+			  menubar);
+	g_signal_connect (menubar->priv->places_item,
+			  "activate",
+			  G_CALLBACK (panel_menu_bar_hide_tooltip),
+			  menubar);
+	g_signal_connect (menubar->priv->desktop_item,
+			  "activate",
+			  G_CALLBACK (panel_menu_bar_hide_tooltip),
+			  menubar);
+
+	/* Reset tooltip when the menu bar is not used */
+	g_signal_connect (GTK_MENU_SHELL (menubar),
+			  "deactivate",
+			  G_CALLBACK (panel_menu_bar_reinit_tooltip),
+			  menubar);
+
+	/* Preset a tooltip that will change when the cursor enters an item
+	 * If we don't do this, the tooltip will not work on the first enter
+	 * event. */
+	gtk_tooltips_set_tip (panel_tooltips,
+			      GTK_WIDGET (menubar),
+			      "", NULL);
+}
+
 static void
 panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 			      PanelMenuBarClass *klass)
@@ -94,6 +198,8 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	menubar->priv->desktop_item = panel_desktop_menu_item_new (FALSE, TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
 			       menubar->priv->desktop_item);
+
+	panel_menu_bar_setup_tooltip (menubar);
 }
 
 static void
@@ -166,7 +272,8 @@ static void
 panel_menu_bar_size_allocate (GtkWidget     *widget,
 			      GtkAllocation *allocation)
 {
-	GtkAllocation old_allocation;
+	GtkAllocation    old_allocation;
+	PanelBackground *background;
 
 	old_allocation.x      = widget->allocation.x;
 	old_allocation.y      = widget->allocation.y;
@@ -181,6 +288,12 @@ panel_menu_bar_size_allocate (GtkWidget     *widget,
 	    old_allocation.height == allocation->height)
 		return;
 
+	background = &PANEL_MENU_BAR (widget)->priv->panel->background;
+
+	if (background->type == PANEL_BACK_NONE ||
+	   (background->type == PANEL_BACK_COLOR && !background->has_alpha))
+		return;
+
 	panel_menu_bar_change_background (PANEL_MENU_BAR (widget));
 }
 
@@ -355,7 +468,7 @@ panel_menu_bar_invoke_menu (PanelMenuBar *menubar,
 		if (error) {
 			panel_error_dialog (screen,
 					    "cannot_exec_gmenu-simple-editor", TRUE,
-					    _("Cannot execute '%s'"),
+					    _("Could not execute '%s'"),
 					    "%s",
 					    "gmenu-simple-editor",
 					    error->message);
@@ -392,95 +505,11 @@ panel_menu_bar_popup_menu (PanelMenuBar *menubar,
 				    gtk_menu_get_attach_widget (menu));
 }
 
-static void
-panel_menu_bar_set_no_background (PanelMenuBar *menubar)
-{
-	GtkRcStyle *rc_style;
-
-	gtk_widget_set_style (GTK_WIDGET (menubar), NULL);
-	rc_style = gtk_rc_style_new ();
-	gtk_widget_modify_style (GTK_WIDGET (menubar), rc_style);
-	gtk_rc_style_unref (rc_style);
-
-}
-
-static void
-panel_menu_bar_set_image_background (PanelMenuBar *menubar)
-{
-	const GdkPixmap  *bg_pixmap;
-	GdkPixmap        *pixmap;
-	GtkStyle         *style;
-	GdkGC            *gc;
-
-	bg_pixmap = panel_background_get_pixmap (&menubar->priv->panel->background);
-	if (!bg_pixmap)
-		return;
-
-	gc = gdk_gc_new (GTK_WIDGET (menubar)->window);
-	g_return_if_fail (GDK_IS_GC (gc));
-
-	pixmap = gdk_pixmap_new (GTK_WIDGET (menubar)->window,
-				 GTK_WIDGET (menubar)->allocation.width,
-				 GTK_WIDGET (menubar)->allocation.height,
-				 -1);
-
-	gdk_draw_drawable (GDK_DRAWABLE (pixmap),
-			   gc, 
-			   GDK_DRAWABLE (bg_pixmap),
-			   GTK_WIDGET (menubar)->allocation.x,
-			   GTK_WIDGET (menubar)->allocation.y,
-			   0, 0,
-			   GTK_WIDGET (menubar)->allocation.width,
-			   GTK_WIDGET (menubar)->allocation.height);
-
-	g_object_unref (gc);
-
-	style = gtk_style_copy (GTK_WIDGET (menubar)->style);
-	if (style->bg_pixmap[GTK_STATE_NORMAL])
-		g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-	style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-	gtk_widget_set_style (GTK_WIDGET (menubar), style);
-	g_object_unref (style);
-
-	g_object_unref (pixmap);
-}
-
-static void
-panel_menu_bar_set_color_background (PanelMenuBar *menubar)
-{
-	const PanelColor *color;
-
-	color = panel_background_get_color (&menubar->priv->panel->background);
-	if (color->alpha != 0xffff) {
-		panel_menu_bar_set_image_background (menubar);
-		return;
-	}
-
-	gtk_widget_modify_bg (GTK_WIDGET (menubar), GTK_STATE_NORMAL, &color->gdk);
-}
-
 void
 panel_menu_bar_change_background (PanelMenuBar *menubar)
 {
-	PanelBackgroundType type;
-
-	panel_menu_bar_set_no_background (menubar);
-
-	type = panel_background_get_type (&menubar->priv->panel->background);
-
-	switch (type) {
-	case PANEL_BACK_NONE:
-		break;
-	case PANEL_BACK_COLOR:
-		panel_menu_bar_set_color_background (menubar);
-		break;
-	case PANEL_BACK_IMAGE:
-		panel_menu_bar_set_image_background (menubar);
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
-	}
+	panel_background_change_background_on_widget (&menubar->priv->panel->background,
+						      GTK_WIDGET (menubar));
 }
 
 static void
