@@ -323,13 +323,10 @@ panel_menu_button_drag_data_get (GtkWidget        *widget,
 				 guint             info,
 				 guint             time)
 {
-	PanelMenuButton *button;
 	char            *drag_data;
 
 	g_return_if_fail (PANEL_IS_MENU_BUTTON (widget));
 
-	button = PANEL_MENU_BUTTON (widget);
-
 	drag_data = g_strdup_printf ("MENU:%d", panel_find_applet_index (widget));
 
 	gtk_selection_data_set (
@@ -1007,7 +1004,7 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
                 if (error) {
                         panel_error_dialog (screen,
                                             "cannot_exec_gmenu-simple-editor", TRUE,
-                                            _("Cannot execute '%s'"),
+                                            _("Could not execute '%s'"),
                                             "%s",
                                             "gmenu-simple-editor",
                                             error->message);
@@ -1037,9 +1034,14 @@ panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
 		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
+
 		icon = panel_menu_button_get_icon (button);
-		gtk_drag_source_set_icon_name (GTK_WIDGET (button), icon);
-		g_free (icon);
+		if (icon != NULL) {
+			gtk_drag_source_set_icon_name (GTK_WIDGET (button),
+						       icon);
+			g_free (icon);
+		}
+
 		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
